Removes all the edges that proved to be either non-significant or smaller than the specified threshold. Returns `bootnetResult` object.
Removes all the edges that proved to be either non-significant or smaller than the specified threshold. Returns `bootnetResult` object.